==> gschedwicons-0.1.0.tar.gz: gschedwicons-0.1.0/src/env_list_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
     
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.
     
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/* env_list_cb.h -- GUI functions for the environment list window */

#ifndef _ENV_LIB_CB_H
#define _ENV_LIB_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_env_list OF((
				void (*hide_cb)(gpointer), gpointer user_data,
				int workload_date));	
extern void dialog_env_list_set_workload_date OF((GtkWidget *dialog_env_list,
						int workload_date));
extern gboolean env_list_delete_event OF((GtkWidget *widget));
extern void env_list_close_clicked OF((GtkButton *button));
extern void env_list_refresh OF((GtkTreeView *view));
extern void env_list_refresh_clicked OF((GtkButton *button));
extern void env_list_refresh_widget OF((GtkWidget *widget));
extern void env_where_used_clicked OF((GtkButton *button));
extern void env_edit_clicked OF((GtkButton *button));
extern void env_edit_menu OF((GtkMenuItem *item));
extern void env_where_used_menu OF((GtkMenuItem *item));
extern gboolean env_on_treeview_cal_button_press_event OF((
						GtkWidget *treeview,
						GdkEventButton *event));
extern gboolean env_on_treeview_cal_popup_menu OF((GtkWidget *treeview));


#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* env_list_cb.h */

/*-----------------============== End Of File ==============-----------------*/

==> gschedwicons-0.1.2.tar.gz: gschedwicons-0.1.2/src/env_list_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* env_list_cb.h -- GUI functions for the environment list window */

#ifndef _ENV_LIB_CB_H
#define _ENV_LIB_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_env_list OF((
				void (*hide_cb)(gpointer), gpointer user_data,
				int workload_date));	
extern void dialog_env_list_set_workload_date OF((GtkWidget *dialog_env_list,
						int workload_date));
extern gboolean env_list_delete_event OF((GtkWidget *widget));
extern void env_list_close_clicked OF((GtkButton *button));
extern void env_list_refresh OF((GtkTreeView *view));
extern void env_list_refresh_clicked OF((GtkButton *button));
extern void env_list_refresh_widget OF((GtkWidget *widget));
extern void env_where_used_clicked OF((GtkButton *button));
extern void env_edit_clicked OF((GtkButton *button));
extern void env_edit_menu OF((GtkMenuItem *item));
extern void env_where_used_menu OF((GtkMenuItem *item));
extern gboolean env_on_treeview_cal_button_press_event OF((
						GtkWidget *treeview,
						GdkEventButton *event));
extern gboolean env_on_treeview_cal_popup_menu OF((GtkWidget *treeview));


#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* env_list_cb.h */

/*-----------------============== End Of File ==============-----------------*/
